Crate chik_puzzle_types

Crate chik_puzzle_types 

Modules

cat
did
nft
offer
singleton
standard

Structs

CoinProof
EveProof
LineageProof

Enums

Memos
The purpose of this type is to be an optional field at the end of a create coin condition or payment in the notarized payment list. It can either be nil (no memos specified) or an extra field that is typically a list of memos (although can technically be any structure).
Proof

Traits

DeriveSynthetic

Functions

mod_by_group_order